@@ -122,7 +122,7 @@ class ANALITZA_EXPORT Operator : public Object
 		virtual bool matches(const Object*, QMap<QString, const Object*>*) const;
 		virtual bool decorate(const QMap< QString, Object** >& ) { return false; }
 		
-		virtual QString visit(ExpressionWriter*) const;
+		virtual QVariant accept(AbstractExpressionVisitor*) const;
 		virtual Operator* copy() const;
 		
 		static const char words[nOfOps][14];
